==> how-to-cook-1.1.0.tgz: package/README.md <==
# 程序员做饭指南

[![build](https://github.com/Anduin2017/HowToCook/actions/workflows/build.yml/badge.svg)](https://github.com/Anduin2017/HowToCook/actions/workflows/build.yml)
[![License](https://img.shields.io/github/license/Anduin2017/HowToCook)](./LICENSE)
[![GitHub contributors](https://img.shields.io/github/contributors/Anduin2017/HowToCook)](https://github.com/Anduin2017/HowToCook/graphs/contributors)
[![npm](https://img.shields.io/npm/v/how-to-cook)](https://www.npmjs.com/package/how-to-cook)

最近在家隔离，出不了门。只能宅在家做饭了。作为程序员，我偶尔在网上找找菜谱和做法。但是这些菜谱往往写法千奇百怪，经常中间莫名出来一些材料。对于习惯了形式语言的程序员来说极其不友好。

所以，我计划自己搜寻菜谱和并结合实际做菜的经验，准备用更清晰精准的描述来整理常见菜的做法，以方便程序员在家做饭。

同样，我希望它是一个由社区驱动和维护的开源项目，使更多人能够一起做一个有趣的仓库。所以非常欢迎大家贡献它~

## 如何贡献

针对发现的问题，直接修改并提交 Pull request 即可。

在写新菜谱时，请复制并修改已有的菜谱模板: [示例菜](https://github.com/Anduin2017/HowToCook/blob/master/dishes/template/%E7%A4%BA%E4%BE%8B%E8%8F%9C/%E7%A4%BA%E4%BE%8B%E8%8F%9C.md?plain=1)。

## 做菜之前

- [厨房准备](./tips/厨房准备.md)
- [如何选择现在吃什么](./tips/如何选择现在吃什么.md)
- [高压力锅](./tips/learn/高压力锅.md)
- [食品安全](./tips/learn/食品安全.md)
- [微波炉](./tips/learn/微波炉.md)
- [学习焯水](./tips/learn/学习焯水.md)
- [学习炒与煎](./tips/learn/学习炒与煎.md)
- [学习凉拌](./tips/learn/学习凉拌.md)
- [学习腌](./tips/learn/学习腌.md)
- [学习蒸](./tips/learn/学习蒸.md)
- [学习煮](./tips/learn/学习煮.md)

## 菜谱

### 家常菜

### 素菜

- [菠菜炒鸡蛋](./dishes/vegetable_dish/菠菜炒鸡蛋/菠菜炒鸡蛋.md)
- [炒滑蛋](./dishes/vegetable_dish/炒滑蛋/炒滑蛋.md)
- [炒青菜](./dishes/vegetable_dish/炒青菜.md)
- [葱煎豆腐](./dishes/vegetable_dish/葱煎豆腐.md)
- [地三鲜](./dishes/vegetable_dish/地三鲜.md)
- [红烧茄子](./dishes/vegetable_dish/红烧茄子.md)
- [虎皮青椒](./dishes/vegetable_dish/虎皮青椒/虎皮青椒.md)
- [鸡蛋羹](./dishes/vegetable_dish/鸡蛋羹/鸡蛋羹.md)
- [微波炉鸡蛋羹](./dishes/vegetable_dish/鸡蛋羹/微波炉鸡蛋羹.md)
- [茄子炖土豆](./dishes/vegetable_dish/茄子炖土豆.md)
- [椒盐玉米](./dishes/vegetable_dish/椒盐玉米/椒盐玉米.md)
- [烤茄子](./dishes/vegetable_dish/烤茄子/烤茄子.md)
- [榄菜肉末四季豆](./dishes/vegetable_dish/榄菜肉末四季豆/榄菜肉末四季豆.md)
- [凉拌黄瓜](./dishes/vegetable_dish/凉拌黄瓜.md)
- [凉拌油麦菜](./dishes/vegetable_dish/凉拌油麦菜.md)
- [蒲烧茄子](./dishes/vegetable_dish/蒲烧茄子.md)
- [上汤娃娃菜](./dishes/vegetable_dish/上汤娃娃菜/上汤娃娃菜.md)
- [水油焖蔬菜](./dishes/vegetable_dish/水油焖蔬菜.md)
- [酸辣土豆丝](./dishes/vegetable_dish/酸辣土豆丝.md)
- [糖拌西红柿](./dishes/vegetable_dish/糖拌西红柿/糖拌西红柿.md)
- [西红柿炒鸡蛋](./dishes/vegetable_dish/西红柿炒鸡蛋.md)

### 荤菜

- [白菜猪肉炖粉条](./dishes/meat_dish/白菜猪肉炖粉条.md)
- [宫保鸡丁](./dishes/meat_dish/宫保鸡丁/宫保鸡丁.md)
- [咕噜肉](./dishes/meat_dish/咕噜肉.md)
- [黑椒牛柳](./dishes/meat_dish/黑椒牛柳/黑椒牛柳.md)
- [简易红烧肉](./dishes/meat_dish/红烧肉/简易红烧肉.md)
- [南派红烧肉](./dishes/meat_dish/红烧肉/南派红烧肉.md)
- [红烧猪蹄](./dishes/meat_dish/红烧猪蹄/红烧猪蹄.md)
- [黄瓜炒肉](./dishes/meat_dish/黄瓜炒肉.md)
- [回锅肉](./dishes/meat_dish/回锅肉.md)
- [尖椒炒牛肉](./dishes/meat_dish/尖椒炒牛肉.md)
- [姜炒鸡](./dishes/meat_dish/姜炒鸡/姜炒鸡.md)
- [酱牛肉](./dishes/meat_dish/酱牛肉/酱牛肉.md)
- [可乐鸡翅](./dishes/meat_dish/可乐鸡翅.md)
- [口水鸡](./dishes/meat_dish/口水鸡/口水鸡.md)
- [辣椒炒肉](./dishes/meat_dish/辣椒炒肉.md)
- [老式锅包肉](./dishes/meat_dish/老式锅包肉/老式锅包肉.md)
- [冷吃兔](./dishes/meat_dish/冷吃兔.md)
- [凉拌鸡丝](./dishes/meat_dish/凉拌鸡丝/凉拌鸡丝.md)
- [萝卜炖羊排](./dishes/meat_dish/萝卜炖羊排.md)
- [麻辣香锅](./dishes/meat_dish/麻辣香锅.md)
- [水煮牛肉](./dishes/meat_dish/水煮牛肉/水煮牛肉.md)
- [水煮肉片](./dishes/meat_dish/水煮肉片.md)
- [蒜苔炒肉末](./dishes/meat_dish/蒜苔炒肉末.md)
- [糖醋里脊](./dishes/meat_dish/糖醋里脊.md)
- [土豆炖排骨](./dishes/meat_dish/土豆炖排骨/土豆炖排骨.md)
- [西红柿牛腩](./dishes/meat_dish/西红柿牛腩/西红柿牛腩.md)
- [西红柿土豆炖牛肉](./dishes/meat_dish/西红柿土豆炖牛肉/西红柿土豆炖牛肉.md)
- [香干芹菜炒肉](./dishes/meat_dish/香干芹菜炒肉/香干芹菜炒肉.md)
- [香干肉丝](./dishes/meat_dish/香干肉丝.md)
- [香菇滑鸡](./dishes/meat_dish/香菇滑鸡/香菇滑鸡.md)
- [小炒黄牛肉](./dishes/meat_dish/小炒黄牛肉/小炒黄牛肉.md)
- [小炒肉](./dishes/meat_dish/小炒肉.md)
- [新疆大盘鸡](./dishes/meat_dish/新疆大盘鸡/新疆大盘鸡.md)
- [血浆鸭](./dishes/meat_dish/血浆鸭/血浆鸭.md)
- [羊排焖面](./dishes/meat_dish/羊排焖面/羊排焖面.md)
- [洋葱炒猪肉](./dishes/meat_dish/洋葱炒猪肉.md)
- [鱼香茄子](./dishes/meat_dish/鱼香茄子/鱼香茄子.md)
- [鱼香肉丝](./dishes/meat_dish/鱼香肉丝.md)
- [孜然牛肉](./dishes/meat_dish/孜然牛肉.md)

### 水产

- [白灼虾](./dishes/aquatic/白灼虾/白灼虾.md)
- [鳊鱼炖豆腐](./dishes/aquatic/鳊鱼炖豆腐/鳊鱼炖豆腐.md)
- [红烧鲤鱼](./dishes/aquatic/红烧鲤鱼.md)
- [红烧鱼头](./dishes/aquatic/红烧鱼头.md)
- [黄油煎虾](./dishes/aquatic/黄油煎虾/黄油煎虾.md)
- [烤鱼](./dishes/aquatic/混合烤鱼/烤鱼.md)
- [咖喱炒蟹](./dishes/aquatic/咖喱炒蟹.md)
- [清蒸鲈鱼](./dishes/aquatic/清蒸鲈鱼/清蒸鲈鱼.md)
- [清蒸生蚝](./dishes/aquatic/清蒸生蚝.md)
- [糖醋鲤鱼](./dishes/aquatic/糖醋鲤鱼/糖醋鲤鱼.md)
- [微波葱姜黑鳕鱼](./dishes/aquatic/微波葱姜黑鳕鱼.md)

### 早餐

- [茶叶蛋](./dishes/breakfast/茶叶蛋.md)
- [鸡蛋三明治](./dishes/breakfast/鸡蛋三明治.md)
- [煎饺](./dishes/breakfast/煎饺.md)
- [空气炸锅面包片](./dishes/breakfast/空气炸锅面包片.md)
- [美式炒蛋](./dishes/breakfast/美式炒蛋.md)
- [牛奶燕麦](./dishes/breakfast/牛奶燕麦.md)
- [水煮玉米](./dishes/breakfast/水煮玉米.md)
- [太阳蛋](./dishes/breakfast/太阳蛋.md)
- [溏心蛋](./dishes/breakfast/溏心蛋.md)
- [吐司果酱](./dishes/breakfast/吐司果酱.md)
- [微波炉蛋糕](./dishes/breakfast/微波炉蛋糕.md)
- [燕麦鸡蛋饼](./dishes/breakfast/燕麦鸡蛋饼.md)
- [蒸花卷](./dishes/breakfast/蒸花卷.md)

### 主食

- [炒方便面](./dishes/staple/炒方便面.md)
- [炒河粉](./dishes/staple/炒河粉.md)
- [炒馍](./dishes/staple/炒馍.md)
- [炒意大利面](./dishes/staple/炒意大利面/炒意大利面.md)
- [蛋炒饭](./dishes/staple/蛋炒饭.md)
- [韩式拌饭](./dishes/staple/韩式拌饭/韩式拌饭.md)
- [醪糟小汤圆](./dishes/staple/醪糟小汤圆.md)
- [老干妈拌面](./dishes/staple/老干妈拌面.md)
- [老友猪肉粉](./dishes/staple/老友猪肉粉/老友猪肉粉.md)
- [烙饼](./dishes/staple/烙饼/烙饼.md)
- [凉粉](./dishes/staple/凉粉/凉粉.md)
- [麻辣减脂荞麦面](./dishes/staple/麻辣减脂荞麦面.md)
- [麻油拌面](./dishes/staple/麻油拌面.md)
- [电饭煲蒸米饭](./dishes/staple/米饭/电饭煲蒸米饭.md)
- [煮锅蒸米饭](./dishes/staple/米饭/煮锅蒸米饭.md)
- [热干面](./dishes/staple/热干面.md)
- [日式咖喱饭](./dishes/staple/日式咖喱饭/日式咖喱饭.md)
- [手工水饺](./dishes/staple/手工水饺.md)
- [汤面](./dishes/staple/汤面.md)
- [微波炉腊肠煲仔饭](./dishes/staple/微波炉腊肠煲仔饭/微波炉腊肠煲仔饭.md)
- [炸酱面](./dishes/staple/炸酱面.md)
- [中式馅饼](./dishes/staple/中式馅饼/中式馅饼.md)
- [煮泡面加蛋](./dishes/staple/煮泡面加蛋.md)
- [披萨饼皮](./dishes/staple/pizza/披萨饼皮.md)

### 半成品加工

- [懒人蛋挞](./dishes/semi-finished/懒人蛋挞/懒人蛋挞.md)
- [凉皮](./dishes/semi-finished/凉皮.md)
- [速冻馄饨](./dishes/semi-finished/速冻馄饨.md)
- [速冻水饺](./dishes/semi-finished/速冻水饺.md)
- [速冻汤圆](./dishes/semi-finished/速冻汤圆/速冻汤圆.md)
- [炸薯条](./dishes/semi-finished/炸薯条/炸薯条.md)

### 汤与粥

- [昂刺鱼豆腐汤](./dishes/soup/昂刺鱼豆腐汤/昂刺鱼豆腐汤.md)
- [金针菇汤](./dishes/soup/金针菇汤.md)
- [菌菇炖乳鸽](./dishes/soup/菌菇炖乳鸽/菌菇炖乳鸽.md)
- [罗宋汤](./dishes/soup/罗宋汤.md)
- [米粥](./dishes/soup/米粥.md)
- [皮蛋瘦肉粥](./dishes/soup/皮蛋瘦肉粥.md)
- [生汆丸子汤](./dishes/soup/生汆丸子汤.md)
- [西红柿鸡蛋汤](./dishes/soup/西红柿鸡蛋汤.md)
- [小米粥](./dishes/soup/小米粥.md)
- [紫菜蛋花汤](./dishes/soup/紫菜蛋花汤.md)

### 饮料

- [耙耙柑茶](./dishes/drink/耙耙柑茶/耙耙柑茶.md)
- [百香果橙子特调](./dishes/drink/百香果橙子特调/百香果橙子特调.md)
- [金菲士](./dishes/drink/金菲士/金菲士.md)
- [金汤力](./dishes/drink/金汤力/金汤力.md)
- [可乐桶](./dishes/drink/可乐桶.md)
- [奶茶](./dishes/drink/奶茶.md)
- [奇异果菠菜特调](./dishes/drink/奇异果菠菜特调/奇异果菠菜特调.md)
- [酸梅汤](./dishes/drink/酸梅汤/酸梅汤.md)
- [酸梅汤（半成品加工）](./dishes/drink/酸梅汤（半成品加工）.md)
- [杨枝甘露](./dishes/drink/杨枝甘露.md)
- [B52轰炸机](./dishes/drink/B52轰炸机.md)

### 酱料和其它材料

- [草莓酱](./dishes/condiment/草莓酱/草莓酱.md)
- [蒜香酱油](./dishes/condiment/蒜香酱油.md)
- [糖醋汁](./dishes/condiment/糖醋汁.md)
- [糖色](./dishes/condiment/糖色.md)
- [油泼辣子](./dishes/condiment/油泼辣子/油泼辣子.md)
- [油酥](./dishes/condiment/油酥.md)
- [炸串酱料](./dishes/condiment/炸串酱料.md)
- [蔗糖糖浆](./dishes/condiment/蔗糖糖浆/蔗糖糖浆.md)

### 甜品

- [奥利奥冰淇淋](./dishes/dessert/奥利奥冰淇淋/奥利奥冰淇淋.md)
- [烤蛋挞](./dishes/dessert/烤蛋挞/烤蛋挞.md)
- [戚风蛋糕](./dishes/dessert/戚风蛋糕.md)
- [提拉米苏](./dishes/dessert/提拉米苏/提拉米苏.md)
- [芋泥雪媚娘](./dishes/dessert/芋泥雪媚娘/芋泥雪媚娘.md)

## 进阶知识学习

如果你已经做了许多上面的菜，对于厨艺已经入门，并且想学习更加高深的烹饪技巧，请继续阅读下面的内容：

- [辅料技巧](./tips/advanced/辅料技巧.md)
- [高级专业术语](./tips/advanced/高级专业术语.md)
- [油温判断技巧](./tips/advanced/油温判断技巧.md)

==> how-to-cook-1.2.0.tgz: package/README.md <==
# 程序员做饭指南

[![build](https://github.com/Anduin2017/HowToCook/actions/workflows/build.yml/badge.svg)](https://github.com/Anduin2017/HowToCook/actions/workflows/build.yml)
[![License](https://img.shields.io/github/license/Anduin2017/HowToCook)](./LICENSE)
[![GitHub contributors](https://img.shields.io/github/contributors/Anduin2017/HowToCook)](https://github.com/Anduin2017/HowToCook/graphs/contributors)
[![npm](https://img.shields.io/npm/v/how-to-cook)](https://www.npmjs.com/package/how-to-cook)

最近在家隔离，出不了门。只能宅在家做饭了。作为程序员，我偶尔在网上找找菜谱和做法。但是这些菜谱往往写法千奇百怪，经常中间莫名出来一些材料。对于习惯了形式语言的程序员来说极其不友好。

所以，我计划自己搜寻菜谱和并结合实际做菜的经验，准备用更清晰精准的描述来整理常见菜的做法，以方便程序员在家做饭。

同样，我希望它是一个由社区驱动和维护的开源项目，使更多人能够一起做一个有趣的仓库。所以非常欢迎大家贡献它~

## 如何贡献

针对发现的问题，直接修改并提交 Pull request 即可。

在写新菜谱时，请复制并修改已有的菜谱模板: [示例菜](https://github.com/Anduin2017/HowToCook/blob/master/dishes/template/%E7%A4%BA%E4%BE%8B%E8%8F%9C/%E7%A4%BA%E4%BE%8B%E8%8F%9C.md?plain=1)。

## 做菜之前

- [厨房准备](./tips/厨房准备.md)
- [如何选择现在吃什么](./tips/如何选择现在吃什么.md)
- [高压力锅](./tips/learn/高压力锅.md)
- [食品安全](./tips/learn/食品安全.md)
- [微波炉](./tips/learn/微波炉.md)
- [学习焯水](./tips/learn/学习焯水.md)
- [学习炒与煎](./tips/learn/学习炒与煎.md)
- [学习凉拌](./tips/learn/学习凉拌.md)
- [学习腌](./tips/learn/学习腌.md)
- [学习蒸](./tips/learn/学习蒸.md)
- [学习煮](./tips/learn/学习煮.md)

## 菜谱

### 家常菜

### 素菜

- [菠菜炒鸡蛋](./dishes/vegetable_dish/菠菜炒鸡蛋/菠菜炒鸡蛋.md)
- [炒滑蛋](./dishes/vegetable_dish/炒滑蛋/炒滑蛋.md)
- [炒青菜](./dishes/vegetable_dish/炒青菜.md)
- [葱煎豆腐](./dishes/vegetable_dish/葱煎豆腐.md)
- [地三鲜](./dishes/vegetable_dish/地三鲜.md)
- [耗油生菜](./dishes/vegetable_dish/耗油生菜.md)
- [红烧茄子](./dishes/vegetable_dish/红烧茄子.md)
- [虎皮青椒](./dishes/vegetable_dish/虎皮青椒/虎皮青椒.md)
- [鸡蛋羹](./dishes/vegetable_dish/鸡蛋羹/鸡蛋羹.md)
- [微波炉鸡蛋羹](./dishes/vegetable_dish/鸡蛋羹/微波炉鸡蛋羹.md)
- [茄子炖土豆](./dishes/vegetable_dish/茄子炖土豆.md)
- [椒盐玉米](./dishes/vegetable_dish/椒盐玉米/椒盐玉米.md)
- [烤茄子](./dishes/vegetable_dish/烤茄子/烤茄子.md)
- [榄菜肉末四季豆](./dishes/vegetable_dish/榄菜肉末四季豆/榄菜肉末四季豆.md)
- [凉拌黄瓜](./dishes/vegetable_dish/凉拌黄瓜.md)
- [凉拌油麦菜](./dishes/vegetable_dish/凉拌油麦菜.md)
- [蒲烧茄子](./dishes/vegetable_dish/蒲烧茄子.md)
- [上汤娃娃菜](./dishes/vegetable_dish/上汤娃娃菜/上汤娃娃菜.md)
- [水油焖蔬菜](./dishes/vegetable_dish/水油焖蔬菜.md)
- [酸辣土豆丝](./dishes/vegetable_dish/酸辣土豆丝.md)
- [糖拌西红柿](./dishes/vegetable_dish/糖拌西红柿/糖拌西红柿.md)
- [西红柿炒鸡蛋](./dishes/vegetable_dish/西红柿炒鸡蛋.md)
- [西葫芦炒鸡蛋](./dishes/vegetable_dish/西葫芦炒鸡蛋/西葫芦炒鸡蛋.md)

### 荤菜

- [白菜猪肉炖粉条](./dishes/meat_dish/白菜猪肉炖粉条.md)
- [宫保鸡丁](./dishes/meat_dish/宫保鸡丁/宫保鸡丁.md)
- [咕噜肉](./dishes/meat_dish/咕噜肉.md)
- [黑椒牛柳](./dishes/meat_dish/黑椒牛柳/黑椒牛柳.md)
- [简易红烧肉](./dishes/meat_dish/红烧肉/简易红烧肉.md)
- [南派红烧肉](./dishes/meat_dish/红烧肉/南派红烧肉.md)
- [红烧猪蹄](./dishes/meat_dish/红烧猪蹄/红烧猪蹄.md)
- [黄瓜炒肉](./dishes/meat_dish/黄瓜炒肉.md)
- [回锅肉](./dishes/meat_dish/回锅肉.md)
- [尖椒炒牛肉](./dishes/meat_dish/尖椒炒牛肉.md)
- [姜炒鸡](./dishes/meat_dish/姜炒鸡/姜炒鸡.md)
- [酱牛肉](./dishes/meat_dish/酱牛肉/酱牛肉.md)
- [可乐鸡翅](./dishes/meat_dish/可乐鸡翅.md)
- [口水鸡](./dishes/meat_dish/口水鸡/口水鸡.md)
- [辣椒炒肉](./dishes/meat_dish/辣椒炒肉.md)
- [老式锅包肉](./dishes/meat_dish/老式锅包肉/老式锅包肉.md)
- [冷吃兔](./dishes/meat_dish/冷吃兔.md)
- [凉拌鸡丝](./dishes/meat_dish/凉拌鸡丝/凉拌鸡丝.md)
- [萝卜炖羊排](./dishes/meat_dish/萝卜炖羊排.md)
- [麻辣香锅](./dishes/meat_dish/麻辣香锅.md)
- [水煮牛肉](./dishes/meat_dish/水煮牛肉/水煮牛肉.md)
- [水煮肉片](./dishes/meat_dish/水煮肉片.md)
- [蒜苔炒肉末](./dishes/meat_dish/蒜苔炒肉末.md)
- [糖醋里脊](./dishes/meat_dish/糖醋里脊.md)
- [土豆炖排骨](./dishes/meat_dish/土豆炖排骨/土豆炖排骨.md)
- [无骨鸡爪](./dishes/meat_dish/无骨鸡爪/无骨鸡爪.md)
- [西红柿牛腩](./dishes/meat_dish/西红柿牛腩/西红柿牛腩.md)
- [西红柿土豆炖牛肉](./dishes/meat_dish/西红柿土豆炖牛肉/西红柿土豆炖牛肉.md)
- [香干芹菜炒肉](./dishes/meat_dish/香干芹菜炒肉/香干芹菜炒肉.md)
- [香干肉丝](./dishes/meat_dish/香干肉丝.md)
- [香菇滑鸡](./dishes/meat_dish/香菇滑鸡/香菇滑鸡.md)
- [小炒黄牛肉](./dishes/meat_dish/小炒黄牛肉/小炒黄牛肉.md)
- [小炒肉](./dishes/meat_dish/小炒肉.md)
- [新疆大盘鸡](./dishes/meat_dish/新疆大盘鸡/新疆大盘鸡.md)
- [血浆鸭](./dishes/meat_dish/血浆鸭/血浆鸭.md)
- [羊排焖面](./dishes/meat_dish/羊排焖面/羊排焖面.md)
- [洋葱炒猪肉](./dishes/meat_dish/洋葱炒猪肉.md)
- [鱼香茄子](./dishes/meat_dish/鱼香茄子/鱼香茄子.md)
- [鱼香肉丝](./dishes/meat_dish/鱼香肉丝.md)
- [孜然牛肉](./dishes/meat_dish/孜然牛肉.md)

### 水产

- [白灼虾](./dishes/aquatic/白灼虾/白灼虾.md)
- [鳊鱼炖豆腐](./dishes/aquatic/鳊鱼炖豆腐/鳊鱼炖豆腐.md)
- [红烧鲤鱼](./dishes/aquatic/红烧鲤鱼.md)
- [红烧鱼头](./dishes/aquatic/红烧鱼头.md)
- [黄油煎虾](./dishes/aquatic/黄油煎虾/黄油煎虾.md)
- [烤鱼](./dishes/aquatic/混合烤鱼/烤鱼.md)
- [咖喱炒蟹](./dishes/aquatic/咖喱炒蟹.md)
- [清蒸鲈鱼](./dishes/aquatic/清蒸鲈鱼/清蒸鲈鱼.md)
- [清蒸生蚝](./dishes/aquatic/清蒸生蚝.md)
- [糖醋鲤鱼](./dishes/aquatic/糖醋鲤鱼/糖醋鲤鱼.md)
- [微波葱姜黑鳕鱼](./dishes/aquatic/微波葱姜黑鳕鱼.md)
- [小龙虾](./dishes/aquatic/小龙虾/小龙虾.md)

### 早餐

- [茶叶蛋](./dishes/breakfast/茶叶蛋.md)
- [鸡蛋三明治](./dishes/breakfast/鸡蛋三明治.md)
- [煎饺](./dishes/breakfast/煎饺.md)
- [空气炸锅面包片](./dishes/breakfast/空气炸锅面包片.md)
- [美式炒蛋](./dishes/breakfast/美式炒蛋.md)
- [牛奶燕麦](./dishes/breakfast/牛奶燕麦.md)
- [水煮玉米](./dishes/breakfast/水煮玉米.md)
- [太阳蛋](./dishes/breakfast/太阳蛋.md)
- [溏心蛋](./dishes/breakfast/溏心蛋.md)
- [吐司果酱](./dishes/breakfast/吐司果酱.md)
- [微波炉蛋糕](./dishes/breakfast/微波炉蛋糕.md)
- [燕麦鸡蛋饼](./dishes/breakfast/燕麦鸡蛋饼.md)
- [蒸花卷](./dishes/breakfast/蒸花卷.md)
- [蒸水蛋](./dishes/breakfast/蒸水蛋.md)

### 主食

- [炒方便面](./dishes/staple/炒方便面.md)
- [炒河粉](./dishes/staple/炒河粉.md)
- [炒馍](./dishes/staple/炒馍.md)
- [炒意大利面](./dishes/staple/炒意大利面/炒意大利面.md)
- [蛋炒饭](./dishes/staple/蛋炒饭.md)
- [韩式拌饭](./dishes/staple/韩式拌饭/韩式拌饭.md)
- [醪糟小汤圆](./dishes/staple/醪糟小汤圆.md)
- [老干妈拌面](./dishes/staple/老干妈拌面.md)
- [老友猪肉粉](./dishes/staple/老友猪肉粉/老友猪肉粉.md)
- [烙饼](./dishes/staple/烙饼/烙饼.md)
- [凉粉](./dishes/staple/凉粉/凉粉.md)
- [麻辣减脂荞麦面](./dishes/staple/麻辣减脂荞麦面.md)
- [麻油拌面](./dishes/staple/麻油拌面.md)
- [电饭煲蒸米饭](./dishes/staple/米饭/电饭煲蒸米饭.md)
- [煮锅蒸米饭](./dishes/staple/米饭/煮锅蒸米饭.md)
- [热干面](./dishes/staple/热干面.md)
- [日式咖喱饭](./dishes/staple/日式咖喱饭/日式咖喱饭.md)
- [手工水饺](./dishes/staple/手工水饺.md)
- [汤面](./dishes/staple/汤面.md)
- [微波炉腊肠煲仔饭](./dishes/staple/微波炉腊肠煲仔饭/微波炉腊肠煲仔饭.md)
- [炸酱面](./dishes/staple/炸酱面.md)
- [中式馅饼](./dishes/staple/中式馅饼/中式馅饼.md)
- [煮泡面加蛋](./dishes/staple/煮泡面加蛋.md)
- [披萨饼皮](./dishes/staple/pizza/披萨饼皮.md)

### 半成品加工

- [懒人蛋挞](./dishes/semi-finished/懒人蛋挞/懒人蛋挞.md)
- [凉皮](./dishes/semi-finished/凉皮.md)
- [速冻馄饨](./dishes/semi-finished/速冻馄饨.md)
- [速冻水饺](./dishes/semi-finished/速冻水饺.md)
- [速冻汤圆](./dishes/semi-finished/速冻汤圆/速冻汤圆.md)
- [炸薯条](./dishes/semi-finished/炸薯条/炸薯条.md)

### 汤与粥

- [昂刺鱼豆腐汤](./dishes/soup/昂刺鱼豆腐汤/昂刺鱼豆腐汤.md)
- [金针菇汤](./dishes/soup/金针菇汤.md)
- [菌菇炖乳鸽](./dishes/soup/菌菇炖乳鸽/菌菇炖乳鸽.md)
- [罗宋汤](./dishes/soup/罗宋汤.md)
- [米粥](./dishes/soup/米粥.md)
- [皮蛋瘦肉粥](./dishes/soup/皮蛋瘦肉粥.md)
- [生汆丸子汤](./dishes/soup/生汆丸子汤.md)
- [西红柿鸡蛋汤](./dishes/soup/西红柿鸡蛋汤.md)
- [小米粥](./dishes/soup/小米粥.md)
- [紫菜蛋花汤](./dishes/soup/紫菜蛋花汤.md)

### 饮料

- [耙耙柑茶](./dishes/drink/耙耙柑茶/耙耙柑茶.md)
- [百香果橙子特调](./dishes/drink/百香果橙子特调/百香果橙子特调.md)
- [金菲士](./dishes/drink/金菲士/金菲士.md)
- [金汤力](./dishes/drink/金汤力/金汤力.md)
- [可乐桶](./dishes/drink/可乐桶.md)
- [奶茶](./dishes/drink/奶茶.md)
- [奇异果菠菜特调](./dishes/drink/奇异果菠菜特调/奇异果菠菜特调.md)
- [酸梅汤](./dishes/drink/酸梅汤/酸梅汤.md)
- [酸梅汤（半成品加工）](./dishes/drink/酸梅汤（半成品加工）.md)
- [杨枝甘露](./dishes/drink/杨枝甘露.md)
- [B52轰炸机](./dishes/drink/B52轰炸机.md)
- [Mojito莫吉托](./dishes/drink/Mojito莫吉托.md)

### 酱料和其它材料

- [草莓酱](./dishes/condiment/草莓酱/草莓酱.md)
- [蒜香酱油](./dishes/condiment/蒜香酱油.md)
- [糖醋汁](./dishes/condiment/糖醋汁.md)
- [糖色](./dishes/condiment/糖色.md)
- [油泼辣子](./dishes/condiment/油泼辣子/油泼辣子.md)
- [油酥](./dishes/condiment/油酥.md)
- [炸串酱料](./dishes/condiment/炸串酱料.md)
- [蔗糖糖浆](./dishes/condiment/蔗糖糖浆/蔗糖糖浆.md)

### 甜品

- [奥利奥冰淇淋](./dishes/dessert/奥利奥冰淇淋/奥利奥冰淇淋.md)
- [烤蛋挞](./dishes/dessert/烤蛋挞/烤蛋挞.md)
- [戚风蛋糕](./dishes/dessert/戚风蛋糕/戚风蛋糕.md)
- [提拉米苏](./dishes/dessert/提拉米苏/提拉米苏.md)
- [雪花酥](./dishes/dessert/雪花酥/雪花酥.md)
- [芋泥雪媚娘](./dishes/dessert/芋泥雪媚娘/芋泥雪媚娘.md)

## 进阶知识学习

如果你已经做了许多上面的菜，对于厨艺已经入门，并且想学习更加高深的烹饪技巧，请继续阅读下面的内容：

- [辅料技巧](./tips/advanced/辅料技巧.md)
- [高级专业术语](./tips/advanced/高级专业术语.md)
- [油温判断技巧](./tips/advanced/油温判断技巧.md)
